@@ -1,15 +1,19 @@
 import argparse
 import pathlib
+import sys
 
 from . import WordSearch
+from . import config
 
 
 class MinSizeAction(argparse.Action):
-    """Restrict argparse `-s`, `--size` value to >=10."""
+    """Restrict argparse `-s`, `--size` inputs."""
 
     def __call__(self, parser, namespace, values, option_string=None):
-        if values < 10:
-            parser.error("minimum size for {0} is 10".format(option_string))
+        min_val = config.min_puzzle_size
+        max_val = config.max_puzzle_size
+        if values < min_val or values > max_val:
+            parser.error(f"{option_string} must be >={min_val} and <={max_val}")
         setattr(namespace, self.dest, values)
 
 
@@ -22,7 +26,13 @@ def cli():
         epilog="Copyright 2021 Josh Duncan (joshbduncan.com)",
     )
     # define all possible arguments
-    parser.add_argument("-w", "--words", nargs="+", help="words to hide in the puzzle")
+    parser.add_argument(
+        "words",
+        type=str,
+        nargs="*",
+        help="words to include in the puzzle",
+        default=sys.stdin,
+    )
     parser.add_argument(
         "-l",
         "--level",
@@ -31,7 +41,11 @@ def cli():
         choices=[1, 2, 3],
     )
     parser.add_argument(
-        "-s", "--size", help="puzzle size >=10", action=MinSizeAction, type=int
+        "-s",
+        "--size",
+        help=f"puzzle size >={config.min_puzzle_size} and <={config.max_puzzle_size}",
+        action=MinSizeAction,
+        type=int,
     )
     parser.add_argument("-k", "--key", help="show answer key", action="store_true")
     parser.add_argument(
@@ -44,23 +58,19 @@ def cli():
         choices=["csv", "pdf"],
     )
     parser.add_argument(
-        "-p",
-        "--path",
-        help="export path for '-e', '--export' flag",
+        "-o",
+        "--output",
+        help="output path for '-e', '--export' flag",
         type=pathlib.Path,
     )
 
     # capture all cli arguments and make sure words were provided
     args = parser.parse_args()
-    if not args.words:
-        parser.error(
-            "You must provide a list of words. Use '-h' or '--help' for more info.\n"
-        )
     # create a new puzzle object from provided arguments
     puzzle = WordSearch(",".join(args.words), level=args.level, size=args.size)
     # show the result
     if args.export:
-        fexport = puzzle.save(path=args.path, format=args.export.upper())
+        fexport = puzzle.save(path=args.output, format=args.export.upper())
         print(f"Puzzle saved: {fexport}")
     else:
         puzzle.show(key=args.key, tabs=args.tabs)
